RcppFarmHash-package: Interface to the Google 'FarmHash' Family of Hash Functions

RcppFarmHash-packageR Documentation

Interface to the Google 'FarmHash' Family of Hash Functions

Description

The Google 'FarmHash' family of hash functions is used by the Google 'BigQuery' data warehouse via the 'FARM_FINGERPRINT' function. This package permits to calculate these hash digest fingerprints directly from R, and uses the included 'FarmHash' files written by G. Pike and copyrighted by Google, Inc.

Package Content

Index: This package was not yet installed at build time.

Maintainer

Dirk Eddelbuettel <edd@debian.org>

Author(s)

Dirk Eddelbuettel [aut, cre] (ORCID: <https://orcid.org/0000-0001-6419-907X>), Geoff Pike [aut] (Author of FarmHash), Google, Inc. [cph] (Copyright for FarmHash)


RcppFarmHash documentation built on Sept. 6, 2026, 5:07 p.m.