| RcppFarmHash-package | R Documentation |
The Google 'FarmHash' family of hash functions is used by the Google 'BigQuery' data warehouse via the 'FARM_FINGERPRINT' function. This package permits to calculate these hash digest fingerprints directly from R, and uses the included 'FarmHash' files written by G. Pike and copyrighted by Google, Inc.
Index: This package was not yet installed at build time.
Dirk Eddelbuettel <edd@debian.org>
Dirk Eddelbuettel [aut, cre] (ORCID: <https://orcid.org/0000-0001-6419-907X>), Geoff Pike [aut] (Author of FarmHash), Google, Inc. [cph] (Copyright for FarmHash)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.